#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pantry
version:              0.8.3
visibility:           public
id:                   pantry-0.8.3-1fUOBeysvqHIa9UMBuUPAR
key:                  pantry-0.8.3-1fUOBeysvqHIa9UMBuUPAR
license:              BSD-3-Clause
copyright:            2018-2022 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/pantry#readme
synopsis:             Content addressable Haskell package management
description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/pantry#readme>

category:             Development
abi:                  8ceb26a96b3daa732cfa0293f9746fba
exposed:              True
exposed-modules:
    Pantry Pantry.Internal Pantry.Internal.AesonExtended
    Pantry.Internal.Companion Pantry.Internal.Stackage
    Pantry.Internal.StaticBytes Pantry.SHA256

hidden-modules:
    Hackage.Security.Client.Repository.HttpLib.HttpClient
    Pantry.Archive Pantry.HTTP Pantry.HPack Pantry.Hackage Pantry.Repo
    Pantry.SQLite Pantry.Storage Pantry.Casa Pantry.Tree Pantry.Types
    System.IsWindows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pantry
hs-libraries:         HSpantry-0.8.3-1fUOBeysvqHIa9UMBuUPAR
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-85YNaCYG8Hg3jpVZvW11rh
    ansi-terminal-1.1-FGQa0jlUQG652QjbTPzRQp base-4.18.2.1
    bytestring-0.11.5.3 casa-client-0.0.3-Gwyc25m8yCz8IfIQx99ERZ
    casa-types-0.0.3-2eMTKMCPIso1dsUdEipIzt
    conduit-1.3.6.1-Ebhy3RBYCl0GjWBSgKr2qO
    conduit-extra-1.3.8-XHp54LgxBs5FJ61JfwryO containers-0.6.7
    crypton-1.0.4-9zX9BeXmsPp8iArap7D2jI
    crypton-conduit-0.2.3-AvTBa1u7LLA4i8MgSpNXm8
    digest-0.0.2.1-JWOwjMkQwx5F9nVaVojfVV
    filelock-0.1.1.8-JC24bqfE6h3GyttO3gcoOh
    generic-deriving-1.14.7-LYKJvJKe5vK1a8EeMbYjWW
    hackage-security-0.6.3.2-LCnSGwKIpYA1jfh0hIgYa7
    hpack-0.38.0-AkNUFPiPPdP6rmjMkgqY0d
    http-client-0.7.19-3FLJdAt6J8p4L1gAjvkadG
    http-client-tls-0.3.6.4-7dT0sTv5wsY6MP7zh2qecM
    http-conduit-2.3.9.1-3boqfqum3tSJEsngKMvY68
    http-download-0.2.1.0-LqSGrvJaQ5hKRReEOWhpXr
    http-types-0.12.4-HnZKitLAUwVLPDe2pzVd02
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    network-uri-2.6.4.2-5id8v7Hi6k898BswkRigYC
    path-0.9.6-GUwP9rFeBAN5l3EDB2w15q
    path-io-1.8.2-440DqrpHDzfBQOPI6fb3Tr
    persistent-2.14.5.2-1TWKEc5YWhQGYYyLJgBq2Y
    persistent-sqlite-2.13.2.0-EcC6xNa9S5j2exDHo1Mqrn
    primitive-0.9.1.0-83Zfb660O3KLVlf4ykfymS
    resourcet-1.2.6-9srQsJ09Mf4Fnt59TzGntH
    rio-0.1.24.0-8aHdfpjjysr9MgX2PUpHzy
    rio-orphans-0.1.2.0-7kTkFPIxELc280lewU5rtn
    rio-prettyprint-0.1.8.0-1MjWvMlZpkDJF0y1WFdN4A
    tar-conduit-0.4.1-BiY9rNqYGJqD1UNz000RDY text-2.0.2
    text-metrics-0.3.3-4bk5NwRyJPMKFwtv6E81q time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-BT1hA0ewLXjcyxJKq27fN
    unliftio-0.2.25.1-6KPQkQ8JwO74KLgDjnPbqv
    unordered-containers-0.2.20.1-1CoVa9Q6EKSEUs7sPAJfW1
    vector-0.13.2.0-7BVLr4DYOHu1u41KuR5SBY
    yaml-0.11.11.2-InKUzrW1mhL5CnUu8qArQ8
    zip-archive-0.4.3.2-DMgrvs9FweEIXDzCyglEUI

haddock-interfaces:   /usr/share/doc/haskell-pantry/html/pantry.haddock
haddock-html:         /usr/share/doc/haskell-pantry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

